==> nextcloud-30.0.5.tgz: nextcloud/apps/firstrunwizard/l10n/zh_CN.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "首次运行显示向导",
    "Add your profile information! For example your email is needed to receive notifications." : "添加你的个人资料信息！例如，需要你的电子邮件来接收通知。",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "添加你的个人资料信息！例如，需要你的电子邮件来接收通知并重置密码。",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "添加您的个人资料信息！设置个人资料图片和全名，以便在所有功能中轻松识别。",
    "Add your profile information! Set a full name for easier recognition across all features." : "添加您的个人资料信息！设置全名，以便在所有功能中轻松识别。",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "添加您的个人资料信息！设置个人资料图片，以便在所有功能中轻松识别。",
    "Schedule work & meetings, synced with all your devices." : "安排工作和会议，与您的所有设备同步。",
    "Keep your colleagues and friends in one place without leaking their private info." : "将您同事朋友的信息保存在一个地方而不会泄露他们的隐私。",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "简单的电子邮件应用，与文件、联系人和日历应用集成。",
    "App recommendation: Tasks" : "应用推荐：任务",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "将各种设备的任务与 Nextcloud 同步，然后在线进行编辑。",
    "App recommendation: Deck" : "应用推荐：看板",
    "Kanban style organization for personal planning and team projects." : "看板式的组织个人计划和团队项目。",
    "App recommendation: Forms" : "推荐应用：表单",
    "Simple surveys and questionnaires, self-hosted" : "简单的自托管调查问卷",
    "App recommendation: Recognize" : "推荐应用：智能识别",
    "Smart media tagging for Nextcloud" : "智能的媒体文件标签分类",
    "App recommendation: Group folders" : "应用推荐：群组文件夹",
    "Admin-configured folders shared by everyone in a group." : "由管理员配置的被用户组所有成员共享的文件夹。",
    "Connect your calendar" : "连接您的日历",
    "Connect your contacts" : "连接您的联系人",
    "Access files via WebDAV" : "通过 WebDAV 访问文件",
    "Download macOS/iOS configuration profile" : "下载 macOS/iOS 配置模板",
    "Desktop client" : "桌面客户端",
    "Android app on Google Play Store" : "Google Play 商店中的安卓应用",
    "Android app on F-Droid" : "F-Droid 中的 Android 应用",
    "iOS app" : "iOS 应用",
    "About & What's new" : "关于&新功能",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud 的欢迎和介绍向导",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "此应用在用户初次登录Nextcloud时启用一个弹窗。此弹窗欢迎新用户来到Nextcloud，包含标准桌面客户端，Android应用和iOS应用的链接。这个窗口也会显示从WebDAV访问Nextcloud的链接。在任何时间，初次运行向导都能通过 设置 目录上的\"关于\"链接再次打开。\n初次运行向导可以定制以满足某些设计需求，或修改链接和消息。可以很容易地按主题设置文档来创建合适的主题，以及改变向导的外观。更多信息请参见初次运行向导文档以及主题设置文档。",
    "Download on Apple app store" : "从苹果应用商店下载",
    "Download on Google play store" : "从Google Play商店下载",
    "Go to previous page" : "回到前一页",
    "Close" : "关闭",
    "More about Nextcloud" : "更多关于 Nextcloud 的信息",
    "Explore more apps ↗" : "发现更多应用 ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "数百款社区开发的应用为您的 Nextcloud 扩展更多功能",
    "Get involved! ↗" : "参与其中！",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "成为构建、设计、翻译和推广Nextcloud的社区的一份子！",
    "Need help? ↗" : "需要帮助？↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "通过管理员、用户和开发者手册进一步熟悉您的 Nextcloud 安装",
    "For large organisations ↗" : "面向大型组织",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "任务关键环境中，Nextcloud Enterprise可提供必须的高级安全和合规特性",
    "Seamless integration with your devices." : "无缝集成到您的设备中",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "使用桌面和移动应用在您的设备间同步文件，并连接您的日历和通讯录",
    "Desktop app ↗" : "桌面应用 ↗",
    "Download For Windows, Mac OS and Linux." : "下载支持 Windows、macOS和Linux的版本",
    "Calendar and contacts ↗" : "日历及通讯录",
    "Connect your calendar and contacts with your devices." : "连接您不同设备间的日历和通讯录",
    "Welcome to {cloudName}!" : "欢迎来到 {cloudName}！",
    "A collaboration platform that puts you in control" : "一个由您掌握的协作平台",
    "Privacy" : "隐私",
    "Host your data and files where you decide." : "把数据和文件保管在您决定的地方",
    "Productivity" : "生产力",
    "Collaborate and communicate across any platform." : "跨任何平台进行沟通和协作",
    "Interoperability" : "互通性",
    "Import and export anything you want with open standards." : "使用开放标准导入导出您想要的任何东西",
    "Community" : "社区",
    "Enjoy constant improvements from a thriving open-source community." : "生机勃勃的开源社区持续优化您的体验",
    "This Nextcloud is on version {version}" : "Nextcloud 的版本为 {version}",
    "Share your opinion about Nextcloud Hub {version}" : "分享您对 Nextcloud Hub {version} 的看法",
    "Share via email" : "通过 e-Mail 分享",
    "Connect other apps to {productName}" : "将其他应用连接到 {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "除了移动应用程序和桌面客户端，你还可以将支持 WebDAV/CalDAV/CardDAV 协议的任何其他软件连接到 {productName}。",
    "Get the apps to sync your files" : "安装应用进行文件同步",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} 让你不管身在何处都可以访问你的文件，我们免费提供各大主要平台上简单易用的桌面和移动客户端。",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "使用{linkStart}应用程序密码{linkEnd}设置同步客户端。这样，如果你丢失该设备，你可以确保可以撤销访问权限。",
    "Server address" : "服务器地址",
    "Use this link to connect your apps and desktop client to this server:" : "使用此链接将您的应用和桌面客户端连接到此服务器：",
    "What's new?" : "有哪些更新？",
    "Nextcloud on all your devices" : "您所有设备上的 Nextcloud",
    "Read more" : "阅读更多",
    "Share on social media" : "在社交媒体上分享",
    "Get started!" : "即刻开始！",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "按 ⌘-C 复制。",
    "Press Ctrl-C to copy." : "按 Ctrl-C 复制。",
    "App recommendation: Nextcloud Calendar" : "应用推荐：Nextcloud 日历",
    "App recommendation: Nextcloud Contacts" : "应用推荐：Nextcloud 联系人",
    "App recommendation: Nextcloud Mail" : "应用推荐：Nextcloud 邮件",
    "About" : "关于",
    "Close dialog" : "关闭对话框",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s 让你不管身在何处都可以访问你的文件，我们免费提供各大主要平台上简单易用的桌面和移动客户端。",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "为同步客户端设置一个<a href=\"%s\">应用密码</a>，这样设备丢失的时候你就可确保撤销访问权限了。",
    "Connect other apps to %s" : "将其他应用连接到 %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "除了移动应用程序和桌面客户端，你还可以将支持 WebDAV/CalDAV/CardDAV 协议的任何其他软件连接到 %s。",
    "Copy link" : "复制链接",
    "Manage your team resources like a pro with Nextcloud Teams" : "使用Nextcloud团队像专业人士一样管理您的团队资源"
},
"nplurals=1; plural=0;");

==> nextcloud-30.0.10.tgz: nextcloud/apps/firstrunwizard/l10n/zh_CN.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "首次运行显示向导",
    "Add your profile information! For example your email is needed to receive notifications." : "添加你的个人资料信息！例如，需要你的电子邮件来接收通知。",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "添加你的个人资料信息！例如，需要你的电子邮件来接收通知并重置密码。",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "添加您的个人资料信息！设置个人资料图片和全名，以便在所有功能中轻松识别。",
    "Add your profile information! Set a full name for easier recognition across all features." : "添加您的个人资料信息！设置全名，以便在所有功能中轻松识别。",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "添加您的个人资料信息！设置个人资料图片，以便在所有功能中轻松识别。",
    "App recommendation: Calendar" : "应用推荐：日历",
    "Schedule work & meetings, synced with all your devices." : "安排工作和会议，与您的所有设备同步。",
    "App recommendation: Contacts" : "应用推荐：联系人",
    "Keep your colleagues and friends in one place without leaking their private info." : "将您同事朋友的信息保存在一个地方而不会泄露他们的隐私。",
    "App recommendation: Mail" : "应用推荐：邮件",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "简单的电子邮件应用，与文件、联系人和日历应用集成。",
    "App recommendation: Tasks" : "应用推荐：任务",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "将各种设备的任务与 Nextcloud 同步，然后在线进行编辑。",
    "App recommendation: Deck" : "应用推荐：看板",
    "Kanban style organization for personal planning and team projects." : "看板式的组织个人计划和团队项目。",
    "App recommendation: Forms" : "推荐应用：表单",
    "Simple surveys and questionnaires, self-hosted" : "简单的自托管调查问卷",
    "App recommendation: Recognize" : "推荐应用：智能识别",
    "Smart media tagging for Nextcloud" : "智能的媒体文件标签分类",
    "App recommendation: Group folders" : "应用推荐：群组文件夹",
    "Admin-configured folders shared by everyone in a group." : "由管理员配置的被用户组所有成员共享的文件夹。",
    "App recommendation: Whiteboard" : "应用推荐：白板",
    "Create and share whiteboards with others and collaborate in real-time." : "创建白板并与他人共享，实时协作。",
    "Connect your calendar" : "连接您的日历",
    "Connect your contacts" : "连接您的联系人",
    "Access files via WebDAV" : "通过 WebDAV 访问文件",
    "Download macOS/iOS configuration profile" : "下载 macOS/iOS 配置模板",
    "Desktop client" : "桌面客户端",
    "Android app on Google Play Store" : "Google Play 商店中的安卓应用",
    "Android app on F-Droid" : "F-Droid 中的 Android 应用",
    "iOS app" : "iOS 应用",
    "About & What's new" : "关于&新功能",
    "A welcome and introduction wizard for Nextcloud" : "Nextcloud 的欢迎和介绍向导",
    "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "此应用在用户初次登录Nextcloud时启用一个弹窗。此弹窗欢迎新用户来到Nextcloud，包含标准桌面客户端，Android应用和iOS应用的链接。这个窗口也会显示从WebDAV访问Nextcloud的链接。在任何时间，初次运行向导都能通过 设置 目录上的\"关于\"链接再次打开。\n初次运行向导可以定制以满足某些设计需求，或修改链接和消息。可以很容易地按主题设置文档来创建合适的主题，以及改变向导的外观。更多信息请参见初次运行向导文档以及主题设置文档。",
    "Download on Apple app store" : "从苹果应用商店下载",
    "Download on Google play store" : "从Google Play商店下载",
    "Go to previous page" : "回到前一页",
    "Close" : "关闭",
    "More about Nextcloud" : "更多关于 Nextcloud 的信息",
    "Explore more apps ↗" : "发现更多应用 ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "数百款社区开发的应用为您的 Nextcloud 扩展更多功能",
    "Get involved! ↗" : "参与其中！",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "成为构建、设计、翻译和推广Nextcloud的社区的一份子！",
    "Need help? ↗" : "需要帮助？↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "通过管理员、用户和开发者手册进一步熟悉您的 Nextcloud 安装",
    "For large organisations ↗" : "面向大型组织",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "任务关键环境中，Nextcloud Enterprise可提供必须的高级安全和合规特性",
    "Seamless integration with your devices." : "无缝集成到您的设备中",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "使用桌面和移动应用在您的设备间同步文件，并连接您的日历和通讯录",
    "Desktop app ↗" : "桌面应用 ↗",
    "Download For Windows, Mac OS and Linux." : "下载支持 Windows、macOS和Linux的版本",
    "Calendar and contacts ↗" : "日历及通讯录",
    "Connect your calendar and contacts with your devices." : "连接您不同设备间的日历和通讯录",
    "Introducing Nextcloud Hub {version}" : "隆重推出 Nextcloud Hub {version}",
    "Welcome to {cloudName}!" : "欢迎使用 {cloudName}！",
    "This Nextcloud is on version {version}" : "Nextcloud 的版本为 {version}",
    "A collaboration platform that puts you in control" : "一个由您掌握的协作平台",
    "Privacy" : "隐私",
    "Host your data and files where you decide." : "把数据和文件保管在您决定的地方",
    "Productivity" : "生产力",
    "Collaborate and communicate across any platform." : "跨任何平台进行沟通和协作",
    "Interoperability" : "互通性",
    "Import and export anything you want with open standards." : "使用开放标准导入导出您想要的任何东西",
    "Community" : "社区",
    "Enjoy constant improvements from a thriving open-source community." : "生机勃勃的开源社区持续优化您的体验",
    "Nextcloud Hub {version} release" : "Nextcloud Hub {version} 发布",
    "Read more about it on the Nextcloud Hub {version} blog" : "在 Nextcloud Hub {version} 博客上阅读更多信息",
    "Find out more on the blog" : "在博客上了解更多",
    "Read the Nextcloud Hub {version} blog" : "阅读 Nextcloud Hub {version} 博客",
    "Share your opinion about Nextcloud Hub {version}" : "分享您对 Nextcloud Hub {version} 的看法",
    "Share via email" : "通过 e-Mail 分享",
    "Share on {socialMedia}" : "在 {socialMedia} 上分享",
    "New in Nextcloud Hub {version}" : "Nextcloud Hub {version} 中的新功能",
    "Connect other apps to {productName}" : "将其他应用连接到 {productName}",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to {productName}." : "除了移动应用程序和桌面客户端，你还可以将支持 WebDAV/CalDAV/CardDAV 协议的任何其他软件连接到 {productName}。",
    "Apps to connect to {productName}" : "要连接到 {productName} 的应用",
    "Set up sync clients using an {linkStart}app password{linkEnd}. That way you can make sure you are able to revoke access in case you lose that device." : "使用{linkStart}应用程序密码{linkEnd}设置同步客户端。这样，如果你丢失该设备，你可以确保可以撤销访问权限。",
    "Get the apps to sync your files" : "安装应用进行文件同步",
    "{productName} gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "{productName} 让你不管身在何处都可以访问你的文件，我们免费提供各大主要平台上简单易用的桌面和移动客户端。",
    "App for syncing" : "用于同步的应用",
    "URL copied" : "URL 已复制",
    "Could not copy the URL, please copy manually" : "无法复制 URL，请手动复制",
    "Server address" : "服务器地址",
    "Use this link to connect your apps and desktop client to this server:" : "使用此链接将您的应用和桌面客户端连接到此服务器：",
    "End-to-end encryption in calls and web" : "通话和网页端到端加密",
    "Performance improvements across all our products" : "我们所有产品的性能改进",
    "Thousands of tweaks for improved UX and stability" : "数千次调整以提高用户体验和稳定性",
    "Your own new personal assistant" : "您自己的新个人助手",
    "Seamless file conversions" : "无缝文件转换",
    "Smarter team sharing with Team folders" : "通过团队文件夹进行更智能的团队共享",
    "Schedule meetings directly in Talk" : "直接在 Talk 中安排会议",
    "Mail you love again: translations, summaries, and mentions" : "发送您喜欢的邮件：翻译、摘要和提及",
    "Get to know the new features of Hub {version}" : "了解 Hub {version} 的新功能",
    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "Nextcloud Hub 10 来了 – 您的模块化和统一的数字工作空间！💫",
    "What's new?" : "有哪些更新？",
    "Nextcloud on all your devices" : "您所有设备上的 Nextcloud",
    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
    "Read more" : "阅读更多",
    "Share on social media" : "在社交媒体上分享",
    "Get started!" : "即刻开始！",
    "App recommendation: Nextcloud Calendar" : "应用推荐：Nextcloud 日历",
    "App recommendation: Nextcloud Contacts" : "应用推荐：Nextcloud 联系人",
    "App recommendation: Nextcloud Mail" : "应用推荐：Nextcloud 邮件",
    "Assistant: chat summaries, Mail reply suggestions, answers based on your data, and more" : "助手：聊天摘要、邮件回复建议、基于您数据的回答等",
    "Interactive previews for files, folders, boards and events" : "文件、文件夹、看板和事件的交互式预览",
    "Federated chat and message editing in Talk" : "Talk 中的联合聊天和消息编辑",
    "Mini-apps based on Tables" : "基于表格的迷你应用",
    "Public Collectives sharing, previews and QR-codes" : "公开收藏集分享、预览和二维码",
    "Manage your team resources like a pro with Nextcloud Teams" : "使用Nextcloud团队像专业人士一样管理您的团队资源",
    "Forms: automatically sync with a spreadsheet" : "表单：自动与电子表格同步",
    "Get to know the new features of Hub 8" : "了解 Hub 8 的新功能",
    "Federated collaboration: file sharing, messaging, calls" : "联合协作：文件共享、消息传递、通话",
    "Nextcloud Whiteboard" : "Nextcloud 白板",
    "Workflow Engine" : "工作流引擎",
    "Safer and swifter mail" : "更安全、更快捷的邮件",
    "Office and PDF templates" : "Office 和 PDF 模板",
    "Chat mode for Nextcloud Assistant" : "Nextcloud 助手的聊天模式",
    "Get to know the new features of Hub 9" : "了解 Hub 9 的新功能"
},
"nplurals=1; plural=0;");
